==> process-decisions-rest-springboot-1.17.0.Final-sources.jar: org/kie/kogito/traffic/Rules267FC1B65547FE8E6DE7B65BC34612BE_LicenseValidationServiceRuleMethods0.java <==
package org.kie.kogito.traffic;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import static org.kie.kogito.traffic.Rules267FC1B65547FE8E6DE7B65BC34612BE.*;

public class Rules267FC1B65547FE8E6DE7B65BC34612BE_LicenseValidationServiceRuleMethods0 {

    /**
     * Rule name: Is driver license valid
     */
    public static org.drools.model.Rule rule_Is_32driver_32license_32valid() {
        final org.drools.model.Variable<org.kie.kogito.traffic.Driver> var_$driver = D.declarationOf(org.kie.kogito.traffic.Driver.class,
                                                                                                     DomainClassesMetadata267FC1B65547FE8E6DE7B65BC34612BE.org_kie_kogito_traffic_Driver_Metadata_INSTANCE,
                                                                                                     "$driver",
                                                                                                     D.entryPoint("driver"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.traffic",
                                            "Is driver license valid")
                                      .unit(org.kie.kogito.traffic.LicenseValidationService.class)
                                      .build(D.pattern(var_$driver).expr("GENERATED_4CD912DCF3AB18199CA3D462B8D7220F",
                                                                         var_currentTime,
                                                                         org.kie.kogito.traffic.P35.LambdaPredicate351306265C796B3345AD091C0ED4ED2A.INSTANCE,
                                                                         D.reactOn("licenseExpiration")),
                                             D.on(var_$driver).execute(org.kie.kogito.traffic.PAA.LambdaConsequenceAA9E857470C2B73F28B1BD8D46FECB0F.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Is driver license expired
     */
    public static org.drools.model.Rule rule_Is_32driver_32license_32expired() {
        final org.drools.model.Variable<org.kie.kogito.traffic.Driver> var_$driver = D.declarationOf(org.kie.kogito.traffic.Driver.class,
                                                                                                     DomainClassesMetadata267FC1B65547FE8E6DE7B65BC34612BE.org_kie_kogito_traffic_Driver_Metadata_INSTANCE,
                                                                                                     "$driver",
                                                                                                     D.entryPoint("driver"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.traffic",
                                            "Is driver license expired")
                                      .unit(org.kie.kogito.traffic.LicenseValidationService.class)
                                      .build(D.pattern(var_$driver).expr("GENERATED_59BB0CFF8FEA50AF474A5DC3E7247CA2",
                                                                         var_currentTime,
                                                                         org.kie.kogito.traffic.P44.LambdaPredicate441778B6387367F454746088664427C8.INSTANCE,
                                                                         D.reactOn("licenseExpiration")),
                                             D.on(var_$driver).execute(org.kie.kogito.traffic.P97.LambdaConsequence97CA032FA7EFCEFE12116A316D69278A.INSTANCE));
        return rule;
    }
}

==> process-decisions-rest-springboot-1.21.0.Final-sources.jar: org/kie/kogito/traffic/Rules267FC1B65547FE8E6DE7B65BC34612BE_LicenseValidationServiceRuleMethods0.java <==
package org.kie.kogito.traffic;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import static org.kie.kogito.traffic.Rules267FC1B65547FE8E6DE7B65BC34612BE.*;

public class Rules267FC1B65547FE8E6DE7B65BC34612BE_LicenseValidationServiceRuleMethods0 {

    /**
     * Rule name: Is driver license valid
     */
    public static org.drools.model.Rule rule_Is_32driver_32license_32valid() {
        final org.drools.model.Variable<org.kie.kogito.traffic.Driver> var_$driver = D.declarationOf(org.kie.kogito.traffic.Driver.class,
                                                                                                     DomainClassesMetadata267FC1B65547FE8E6DE7B65BC34612BE.org_kie_kogito_traffic_Driver_Metadata_INSTANCE,
                                                                                                     "$driver",
                                                                                                     D.entryPoint("driver"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.traffic",
                                            "Is driver license valid")
                                      .unit(org.kie.kogito.traffic.LicenseValidationService.class)
                                      .build(D.pattern(var_$driver).expr("GENERATED_4CD912DCF3AB18199CA3D462B8D7220F",
                                                                         var_currentTime,
                                                                         org.kie.kogito.traffic.P96.LambdaPredicate963BEFBD7496099644F31F0F4AEA4FCD.INSTANCE,
                                                                         D.reactOn("licenseExpiration")),
                                             D.on(var_$driver).execute(org.kie.kogito.traffic.PAA.LambdaConsequenceAA9E857470C2B73F28B1BD8D46FECB0F.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Is driver license expired
     */
    public static org.drools.model.Rule rule_Is_32driver_32license_32expired() {
        final org.drools.model.Variable<org.kie.kogito.traffic.Driver> var_$driver = D.declarationOf(org.kie.kogito.traffic.Driver.class,
                                                                                                     DomainClassesMetadata267FC1B65547FE8E6DE7B65BC34612BE.org_kie_kogito_traffic_Driver_Metadata_INSTANCE,
                                                                                                     "$driver",
                                                                                                     D.entryPoint("driver"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.traffic",
                                            "Is driver license expired")
                                      .unit(org.kie.kogito.traffic.LicenseValidationService.class)
                                      .build(D.pattern(var_$driver).expr("GENERATED_59BB0CFF8FEA50AF474A5DC3E7247CA2",
                                                                         var_currentTime,
                                                                         org.kie.kogito.traffic.P3B.LambdaPredicate3B68A5A18724271FD904F39E68C50023.INSTANCE,
                                                                         D.reactOn("licenseExpiration")),
                                             D.on(var_$driver).execute(org.kie.kogito.traffic.P97.LambdaConsequence97CA032FA7EFCEFE12116A316D69278A.INSTANCE));
        return rule;
    }
}
